"use strict";
var fs = require('fs');
var presets_1 = require('./presets');
var validateMessage = function (message, options) {
    if (options === void 0) { options = {}; }
    if (!message) {
        return false;
    }
    message = message.trim();
    options = Object.assign({
        preset: 'angular'
    }, options);
    var preset = presets_1.default[options.preset];
    if (!preset) {
        throw new Error("Preset '" + options.preset + "' does not exist. A preset must be provided");
    }
    var validate = preset.validate, ignorePattern = preset.ignorePattern;
    if (ignorePattern && ignorePattern.test(message)) {
        if (!process.env.CI) {
            console.warn('Commit message validation ignored.');
        }
        return true;
    }
    return validate(message);
};
exports.validateMessage = validateMessage;
var getMessageFromBuffer = function (buffer) {
    return buffer.toString();
};
var validateMessageFromFile = function (file, options) {
    if (options === void 0) { options = {}; }
    var buffer = fs.readFileSync(file);
    var message = getMessageFromBuffer(buffer);
    return validateMessage(message, options);
};
exports.validateMessageFromFile = validateMessageFromFile;
